// Copyright (c) 2022 Dominic Masters
// 
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT

#pragma once
#include "RenderTarget.hpp"

namespace Dawn {
  class DawnGame;

  class IRenderManager {
    public:
      std::weak_ptr<DawnGame> game;

      /**
       * Returns the primary render target (the backbuffer) that draws directly
       * to the screen.
       * 
       * @return Shared pointer to the backbuffer render target.
       */
      virtual std::shared_ptr<RenderTarget> getBackBuffer() = 0;

      /**
       * Initialize this render manager.
       */
      virtual void init() = 0;

      /**
       * Perform a synchronous frame update on the render manager.
       */
      virtual void update() = 0;
  };
}