// Copyright (c) 2022 Dominic Masters
// 
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT

#pragma once
#include "display/_RenderManager.hpp"

namespace Dawn {
  class BackBufferRenderTarget;

  class RenderManager :
    public IRenderManager,
    public std::enable_shared_from_this<RenderManager>
  {

    public:
      std::shared_ptr<BackBufferRenderTarget> renderTarget;
    
      /**
       * Construct a new RenderManager for a game instance.
       * 
       * @param game Game instance this render manager belongs to.
       */
      RenderManager(std::weak_ptr<DawnGame> game);

      std::shared_ptr<RenderTarget> getBackBuffer() override;
      void init() override;
      void update() override;
      
      /**
       * Destroy a previously initialized RenderManager.
       */
      ~RenderManager();
  };
}